@@ -1,6 +1,6 @@
 <?php
 /*
-Copyright (c) 2007-2008, Till Brehm, projektfarm Gmbh and Oliver Vogel www.muv.com
+Copyright (c) 2007-2010, Till Brehm, projektfarm Gmbh and Oliver Vogel www.muv.com
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -38,13 +38,12 @@ $tform_def_file = "form/client_template.tform.php";
 * End Form configuration
 ******************************************/
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
-require_once('tools.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 //* Check permissions for module
 $app->auth->check_module_permissions('client');
-if(!$_SESSION["s"]["user"]["typ"] == 'admin') die('Client-Templates are only for Admins.');
+if($_SESSION["s"]["user"]["typ"] != 'admin' && !$app->auth->has_clients($_SESSION['s']['user']['userid'])) die('Client-Templates are for Admins and Resellers only.');
 
 // Loading classes
 $app->uses('tpl,tform,tform_actions');
@@ -52,12 +51,25 @@ $app->load('tform_actions');
 
 class page_action extends tform_actions {
 
-	function onBeforeUpdate() {
+	
+	function onSubmit() {
 		global $app;
 		
+		//* Resellers shall not be able to create another reseller or set reseller specific settings
+		if($_SESSION["s"]["user"]["typ"] == 'user') {
+			$this->dataRecord['limit_client'] = 0;
+			$this->dataRecord['limit_domainmodule'] = 0;
+		}
+		
+		parent::onSubmit();
+	}
+	
+	function onBeforeUpdate() {
+		global $app;
+
 		if(isset($this->dataRecord['template_type'])) {
 			//* Check if the template_type has been changed
-			$rec = $app->db->queryOneRecord("SELECT template_type from client_template WHERE template_id = ".$this->id);
+			$rec = $app->db->queryOneRecord("SELECT template_type from client_template WHERE template_id = ?", $this->id);
 			if($rec['template_type'] != $this->dataRecord['template_type']) {
 				//* Add a error message and switch back to old server
 				$app->tform->errorMessage .= $app->lng('The template type can not be changed.');
@@ -66,30 +78,40 @@ class page_action extends tform_actions {
 			unset($rec);
 		}
 	}
-	
-	
+
+
 	/*
 	 This function is called automatically right after
 	 the data was successful updated in the database.
 	*/
 	function onAfterUpdate() {
 		global $app;
-		
+
+		$app->uses('client_templates');
+		if (isset($this->dataRecord["template_type"])) {
+			$template_type = $this->dataRecord["template_type"];
+		} else {
+			$tmp = $app->tform->getDataRecord($this->id);
+			$template_type = $tmp['template_type'];
+		}
+
 		/*
 		 * the template has changed. apply the new data to all clients
 		 */
-		if ($this->dataRecord["template_type"] == 'm'){
-			$sql = "SELECT client_id FROM client WHERE template_master = " . $this->id;
+		if ($template_type == 'm'){
+			$sql = "SELECT client_id FROM client WHERE template_master = ?";
+			$clients = $app->db->queryAllRecords($sql, $this->id);
 		} else {
-			$sql = "SELECT client_id FROM client WHERE template_additional LIKE '%/" . $this->id . '/%"';
+			$sql = "SELECT client_id FROM client WHERE template_additional LIKE ? OR template_additional LIKE ? OR template_additional LIKE ? UNION SELECT client_id FROM client_template_assigned WHERE client_template_id = ?";
+			$clients = $app->db->queryAllRecords($sql, '%/' . $this->id . '/%', $this->id . '/%', '%/' . $this->id, $this->id);
 		}
-		$clients = $app->db->queryAllRecords($sql);
 		if (is_array($clients)){
 			foreach ($clients as $client){
-				applyClientTemplates($client['client_id']);
+				$app->client_templates->apply_client_templates($client['client_id']);
 			}
 		}
 	}
+
 }
 
 $page = new page_action;
