@@ -38,8 +38,8 @@ $tform_def_file = "form/mail_transport.tform.php";
 * End Form configuration
 ******************************************/
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 //* Check permissions for module
 $app->auth->check_module_permissions('mail');
@@ -50,10 +50,10 @@ $app->uses('tpl,tform,tform_actions');
 $app->load('tform_actions');
 
 class page_action extends tform_actions {
-	
+
 	function onShowNew() {
 		global $app, $conf;
-		
+
 		// we will check only users, not admins
 		if($_SESSION["s"]["user"]["typ"] == 'user') {
 			if(!$app->tform->checkClientLimit('limit_mailrouting')) {
@@ -63,33 +63,41 @@ class page_action extends tform_actions {
 				$app->error('Reseller: '.$app->tform->wordbook["limit_mailrouting_txt"]);
 			}
 		}
-		
+
 		parent::onShowNew();
 	}
-	
+
 	function onShowEnd() {
 		global $app, $conf;
-		
-		$tmp_parts = explode(":",$this->dataRecord["transport"]);
-		if(empty($this->id) && empty($tmp_parts[0])) {
-			$rec["type"] = 'smtp';
+
+		$types = array('smtp' => 'smtp', 'uucp' => 'uucp', 'slow' => 'slow', 'error' => 'error', 'custom' => 'custom', '' => 'null');
+		$tmp_parts = explode(":", $this->dataRecord["transport"]);
+		if(!empty($this->id) && !stristr($this->dataRecord["transport"], ':')) {
+			$rec["type"] = 'custom';
 		} else {
-			$rec["type"] = $tmp_parts[0];
+			if(empty($this->id) && empty($tmp_parts[0])) {
+				$rec["type"] = 'smtp';
+			} else {
+				$rec["type"] = $types[$tmp_parts[0]] ? $tmp_parts[0] : 'custom';
+			}
 		}
-		if(@$tmp_parts[2] != '') {
+		if($rec["type"] == 'custom') {
+			$dest = $this->dataRecord["transport"];
+		} elseif(!empty($tmp_parts[2])) {
 			$dest = @$tmp_parts[1].':'.@$tmp_parts[2];
-		} else {
+		} elseif(!empty($tmp_parts[1]) || $this->dataRecord["transport"] == ":") {
 			$dest = $tmp_parts[1];
+		} else {
+			$dest = $this->dataRecord["transport"];
 		}
-		if(@substr($dest,0,1) == '[') {
+		if(@substr($dest, 0, 1) == '[') {
 			$rec["mx"] = 'checked="CHECKED"';
-			$rec["destination"] = @str_replace(']','',@str_replace('[','',$dest));
+			$rec["destination"] = @str_replace(']', '', @str_replace('[', '', $dest));
 		} else {
 			$rec["mx"] = '';
 			$rec["destination"] = @$dest;
 		}
-		
-		$types = array('smtp' => 'smtp','uucp' => 'uucp','slow' => 'slow', 'error' => 'error', '' => 'null');
+
 		$type_select = '';
 		if(is_array($types)) {
 			foreach( $types as $key => $val) {
@@ -101,7 +109,7 @@ class page_action extends tform_actions {
 		$app->tpl->setVar($rec);
 		unset($type);
 		unset($types);
-		
+
 		parent::onShowEnd();
 	}
 
@@ -123,27 +131,27 @@ class page_action extends tform_actions {
 
 	function onSubmit() {
 		global $app, $conf;
-				
+
 		// Check the client limits, if user is not the admin
 		if($_SESSION["s"]["user"]["typ"] != 'admin') { // if user is not admin
 			// Get the limits of the client
-			$client_group_id = $_SESSION["s"]["user"]["default_group"];
-			$client = $app->db->queryOneRecord("SELECT limit_mailrouting FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
+			$client_group_id = $app->functions->intval($_SESSION["s"]["user"]["default_group"]);
+			$client = $app->db->queryOneRecord("SELECT limit_mailrouting FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
 
 			// Check if the user may add another transport.
 			if($this->id == 0 && $client["limit_mailrouting"] >= 0) {
-				$tmp = $app->db->queryOneRecord("SELECT count(transport_id) as number FROM mail_transport WHERE sys_groupid = $client_group_id");
+				$tmp = $app->db->queryOneRecord("SELECT count(transport_id) as number FROM mail_transport WHERE sys_groupid = ?", $client_group_id);
 				if($tmp["number"] >= $client["limit_mailrouting"]) {
 					$app->tform->errorMessage .= $app->tform->wordbook["limit_mailrouting_txt"]."<br>";
 				}
 				unset($tmp);
 			}
 		} // end if user is not admin
-		
+
 		//* Compose transport field
 		if($this->dataRecord["mx"] == 'y') {
-			if(stristr($this->dataRecord["destination"],':')) {
-				$tmp_parts = explode(":",$this->dataRecord["destination"]);
+			if(stristr($this->dataRecord["destination"], ':')) {
+				$tmp_parts = explode(":", $this->dataRecord["destination"]);
 				$transport = '['.$tmp_parts[0].']:'.$tmp_parts[1];
 			} else {
 				$transport = '['.$this->dataRecord["destination"].']';
@@ -151,17 +159,23 @@ class page_action extends tform_actions {
 		} else {
 			$transport = $this->dataRecord["destination"];
 		}
-		$this->dataRecord["transport"] = $this->dataRecord["type"].':'.$transport;
+
+		if($this->dataRecord["type"] == 'custom') {
+			$this->dataRecord["transport"] = $transport;
+		} else {
+			$this->dataRecord["transport"] = $this->dataRecord["type"].':'.$transport;
+		}
+
 		unset($this->dataRecord["type"]);
 		unset($this->dataRecord["mx"]);
 		unset($this->dataRecord["destination"]);
-		
+
 		parent::onSubmit();
 	}
-	
+
 }
 
 $page = new page_action;
 $page->onLoad();
 
-?>
\ No newline at end of file
+?>
