@@ -1,6 +1,6 @@
 <?php
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 /******************************************
 * Begin Form configuration
@@ -21,4 +21,4 @@ $app->uses('listform_actions');
 $app->listform_actions->onLoad();
 
 
-?>
\ No newline at end of file
+?>
