@@ -28,23 +28,24 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
+global $app, $conf;
 
-/******************************************
-* Begin Form configuration
-******************************************/
-
-$tform_def_file = "form/user_settings.tform.php";
-
-/******************************************
-* End Form configuration
-******************************************/
-
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 //* Check permissions for module
 $app->auth->check_module_permissions('tools');
 
-echo '<p class="frmTextHead">'.$app->lng('ISPConfig Tools').'</p>';
+$app->uses('tpl');
 
-?>
\ No newline at end of file
+$app->tpl->newTemplate('listpage.tpl.htm');
+$app->tpl->setInclude('content_tpl', 'templates/index.htm');
+
+$lng_file = 'lib/lang/'.$_SESSION['s']['language'].'_index.lng';
+include $lng_file;
+
+$app->tpl->setVar($wb);
+
+$app->tpl_defaults();
+$app->tpl->pparse();
+?>
